diff --git a/README.md b/README.md
index 3a33a463..eb0eb77b 100644
--- a/README.md
+++ b/README.md
@@ -6,7 +6,7 @@ Summary
-------
Auto Screen Capture is a small and portable screen capture utility for gamers, designers, and testers.
-The information presented in this README refers to the latest version (2.3.3.9).
+(The information presented in this README refers to version 2.3.3.9)
The application enables you to automatically take screenshots at a chosen interval. For example, you may want to capture the progress of playing through a game's level or track your progress on a long project.
diff --git a/changelog.txt b/changelog.txt
index ae83fef9..a20ecb99 100644
--- a/changelog.txt
+++ b/changelog.txt
@@ -4,6 +4,7 @@ Auto Screen Capture by Gavin Kendall
Codename "Boombayah"
+2.3.4.0 Screenshots can be sent to a file server either from the main interface window or with a Trigger. The SMTP and SFTP settings are in their own XML files and can be configured. Help system is available but still early in development.
2.3.3.9 Dashboard introduced so you can have an overview of all screens and regions.
2.3.3.8 Screen now has Source (such as Graphics Card and Operating System), X, Y, Width, and Height. Removed "Resolution Ratio" option for better screen capture performance. Removed internal screen dictionary refresh from Windows because we now use X, Y, Width, and Height either from Graphics Card or from Operating System and these values can now be adjusted. Module tab page layout style changed to be multi-line. Refactored code to reduce usage of static classes and static variables for better memory management. Removed calls to GC Collect. Changed screen capture method. "Region Select / Auto Save" region is no longer created when application initialized. "Region Select / Auto Save" screenshots are now shown in all screenshot tabs.
2.3.3.7 Memory leak fix.
diff --git a/help/FormHelp.Designer.cs b/help/FormHelp.Designer.cs
index c78400d5..466876c7 100644
--- a/help/FormHelp.Designer.cs
+++ b/help/FormHelp.Designer.cs
@@ -73,7 +73,7 @@ private void InitializeComponent()
this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
this.MinimumSize = new System.Drawing.Size(704, 433);
this.Name = "FormHelp";
- this.Text = "Auto Screen Capture - Help";
+ this.Text = "Auto Screen Capture - Help (BETA)";
this.TopMost = true;
this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.FormHelp_FormClosing);
this.Load += new System.EventHandler(this.FormHelp_Load);
diff --git a/help/FormHelp.cs b/help/FormHelp.cs
index a091b3f6..994ecbb3 100644
--- a/help/FormHelp.cs
+++ b/help/FormHelp.cs
@@ -38,7 +38,7 @@ public FormHelp()
private void FormHelp_Load(object sender, System.EventArgs e)
{
listBoxHelpItems.Items.Add("Welcome");
- listBoxHelpItems.Items.Add("Setup and First Run");
+ //listBoxHelpItems.Items.Add("Setup and First Run");
listBoxHelpItems.SelectedIndex = 0;
}
diff --git a/help/help-0-Welcome.rtf b/help/help-0-Welcome.rtf
index c99ae678..362b8e29 100644
Binary files a/help/help-0-Welcome.rtf and b/help/help-0-Welcome.rtf differ
diff --git a/images/screen.png b/images/screen.png
index a8180664..d040bd02 100644
Binary files a/images/screen.png and b/images/screen.png differ
diff --git a/interface/FormAbout.Designer.cs b/interface/FormAbout.Designer.cs
index 66e8d890..4acc44de 100644
--- a/interface/FormAbout.Designer.cs
+++ b/interface/FormAbout.Designer.cs
@@ -32,20 +32,20 @@ private void InitializeComponent()
this.tabControlAbout = new System.Windows.Forms.TabControl();
this.tabPageApplication = new System.Windows.Forms.TabPage();
this.richTextBoxApplication = new System.Windows.Forms.RichTextBox();
- this.tabPageLicense = new System.Windows.Forms.TabPage();
- this.richTextBoxLicense = new System.Windows.Forms.RichTextBox();
+ this.tabPageReleaseNotes = new System.Windows.Forms.TabPage();
+ this.richTextBoxReleaseNotes = new System.Windows.Forms.RichTextBox();
this.tabPageChangelog = new System.Windows.Forms.TabPage();
this.richTextBoxChangelog = new System.Windows.Forms.RichTextBox();
+ this.tabPageLicense = new System.Windows.Forms.TabPage();
+ this.richTextBoxLicense = new System.Windows.Forms.RichTextBox();
this.tabPageDeveloper = new System.Windows.Forms.TabPage();
this.richTextBoxDeveloper = new System.Windows.Forms.RichTextBox();
- this.tabPageReleaseNotes = new System.Windows.Forms.TabPage();
- this.richTextBoxReleaseNotes = new System.Windows.Forms.RichTextBox();
this.tabControlAbout.SuspendLayout();
this.tabPageApplication.SuspendLayout();
- this.tabPageLicense.SuspendLayout();
+ this.tabPageReleaseNotes.SuspendLayout();
this.tabPageChangelog.SuspendLayout();
+ this.tabPageLicense.SuspendLayout();
this.tabPageDeveloper.SuspendLayout();
- this.tabPageReleaseNotes.SuspendLayout();
this.SuspendLayout();
//
// tabControlAbout
@@ -88,30 +88,30 @@ private void InitializeComponent()
this.richTextBoxApplication.TabStop = false;
this.richTextBoxApplication.Text = resources.GetString("richTextBoxApplication.Text");
//
- // tabPageLicense
+ // tabPageReleaseNotes
//
- this.tabPageLicense.Controls.Add(this.richTextBoxLicense);
- this.tabPageLicense.Location = new System.Drawing.Point(4, 22);
- this.tabPageLicense.Name = "tabPageLicense";
- this.tabPageLicense.Padding = new System.Windows.Forms.Padding(3);
- this.tabPageLicense.Size = new System.Drawing.Size(545, 293);
- this.tabPageLicense.TabIndex = 1;
- this.tabPageLicense.Text = "License";
- this.tabPageLicense.UseVisualStyleBackColor = true;
+ this.tabPageReleaseNotes.Controls.Add(this.richTextBoxReleaseNotes);
+ this.tabPageReleaseNotes.Location = new System.Drawing.Point(4, 22);
+ this.tabPageReleaseNotes.Name = "tabPageReleaseNotes";
+ this.tabPageReleaseNotes.Padding = new System.Windows.Forms.Padding(3);
+ this.tabPageReleaseNotes.Size = new System.Drawing.Size(545, 293);
+ this.tabPageReleaseNotes.TabIndex = 3;
+ this.tabPageReleaseNotes.Text = "Release Notes";
+ this.tabPageReleaseNotes.UseVisualStyleBackColor = true;
//
- // richTextBoxLicense
+ // richTextBoxReleaseNotes
//
- this.richTextBoxLicense.BackColor = System.Drawing.Color.White;
- this.richTextBoxLicense.DetectUrls = false;
- this.richTextBoxLicense.Dock = System.Windows.Forms.DockStyle.Fill;
- this.richTextBoxLicense.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.richTextBoxLicense.Location = new System.Drawing.Point(3, 3);
- this.richTextBoxLicense.Name = "richTextBoxLicense";
- this.richTextBoxLicense.ReadOnly = true;
- this.richTextBoxLicense.Size = new System.Drawing.Size(539, 287);
- this.richTextBoxLicense.TabIndex = 0;
- this.richTextBoxLicense.TabStop = false;
- this.richTextBoxLicense.Text = resources.GetString("richTextBoxLicense.Text");
+ this.richTextBoxReleaseNotes.BackColor = System.Drawing.Color.White;
+ this.richTextBoxReleaseNotes.DetectUrls = false;
+ this.richTextBoxReleaseNotes.Dock = System.Windows.Forms.DockStyle.Fill;
+ this.richTextBoxReleaseNotes.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.richTextBoxReleaseNotes.Location = new System.Drawing.Point(3, 3);
+ this.richTextBoxReleaseNotes.Name = "richTextBoxReleaseNotes";
+ this.richTextBoxReleaseNotes.ReadOnly = true;
+ this.richTextBoxReleaseNotes.Size = new System.Drawing.Size(539, 287);
+ this.richTextBoxReleaseNotes.TabIndex = 1;
+ this.richTextBoxReleaseNotes.TabStop = false;
+ this.richTextBoxReleaseNotes.Text = resources.GetString("richTextBoxReleaseNotes.Text");
//
// tabPageChangelog
//
@@ -138,6 +138,31 @@ private void InitializeComponent()
this.richTextBoxChangelog.Text = resources.GetString("richTextBoxChangelog.Text");
this.richTextBoxChangelog.WordWrap = false;
//
+ // tabPageLicense
+ //
+ this.tabPageLicense.Controls.Add(this.richTextBoxLicense);
+ this.tabPageLicense.Location = new System.Drawing.Point(4, 22);
+ this.tabPageLicense.Name = "tabPageLicense";
+ this.tabPageLicense.Padding = new System.Windows.Forms.Padding(3);
+ this.tabPageLicense.Size = new System.Drawing.Size(545, 293);
+ this.tabPageLicense.TabIndex = 1;
+ this.tabPageLicense.Text = "License";
+ this.tabPageLicense.UseVisualStyleBackColor = true;
+ //
+ // richTextBoxLicense
+ //
+ this.richTextBoxLicense.BackColor = System.Drawing.Color.White;
+ this.richTextBoxLicense.DetectUrls = false;
+ this.richTextBoxLicense.Dock = System.Windows.Forms.DockStyle.Fill;
+ this.richTextBoxLicense.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.richTextBoxLicense.Location = new System.Drawing.Point(3, 3);
+ this.richTextBoxLicense.Name = "richTextBoxLicense";
+ this.richTextBoxLicense.ReadOnly = true;
+ this.richTextBoxLicense.Size = new System.Drawing.Size(539, 287);
+ this.richTextBoxLicense.TabIndex = 0;
+ this.richTextBoxLicense.TabStop = false;
+ this.richTextBoxLicense.Text = resources.GetString("richTextBoxLicense.Text");
+ //
// tabPageDeveloper
//
this.tabPageDeveloper.Controls.Add(this.richTextBoxDeveloper);
@@ -160,32 +185,7 @@ private void InitializeComponent()
this.richTextBoxDeveloper.Size = new System.Drawing.Size(545, 293);
this.richTextBoxDeveloper.TabIndex = 1;
this.richTextBoxDeveloper.TabStop = false;
- this.richTextBoxDeveloper.Text = "";
- //
- // tabPageReleaseNotes
- //
- this.tabPageReleaseNotes.Controls.Add(this.richTextBoxReleaseNotes);
- this.tabPageReleaseNotes.Location = new System.Drawing.Point(4, 22);
- this.tabPageReleaseNotes.Name = "tabPageReleaseNotes";
- this.tabPageReleaseNotes.Padding = new System.Windows.Forms.Padding(3);
- this.tabPageReleaseNotes.Size = new System.Drawing.Size(545, 293);
- this.tabPageReleaseNotes.TabIndex = 3;
- this.tabPageReleaseNotes.Text = "Release Notes";
- this.tabPageReleaseNotes.UseVisualStyleBackColor = true;
- //
- // richTextBoxReleaseNotes
- //
- this.richTextBoxReleaseNotes.BackColor = System.Drawing.Color.White;
- this.richTextBoxReleaseNotes.DetectUrls = false;
- this.richTextBoxReleaseNotes.Dock = System.Windows.Forms.DockStyle.Fill;
- this.richTextBoxReleaseNotes.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.richTextBoxReleaseNotes.Location = new System.Drawing.Point(3, 3);
- this.richTextBoxReleaseNotes.Name = "richTextBoxReleaseNotes";
- this.richTextBoxReleaseNotes.ReadOnly = true;
- this.richTextBoxReleaseNotes.Size = new System.Drawing.Size(539, 287);
- this.richTextBoxReleaseNotes.TabIndex = 1;
- this.richTextBoxReleaseNotes.TabStop = false;
- this.richTextBoxReleaseNotes.Text = "";
+ this.richTextBoxDeveloper.Text = resources.GetString("richTextBoxDeveloper.Text");
//
// FormAbout
//
@@ -203,10 +203,10 @@ private void InitializeComponent()
this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.FormAbout_FormClosing);
this.tabControlAbout.ResumeLayout(false);
this.tabPageApplication.ResumeLayout(false);
- this.tabPageLicense.ResumeLayout(false);
+ this.tabPageReleaseNotes.ResumeLayout(false);
this.tabPageChangelog.ResumeLayout(false);
+ this.tabPageLicense.ResumeLayout(false);
this.tabPageDeveloper.ResumeLayout(false);
- this.tabPageReleaseNotes.ResumeLayout(false);
this.ResumeLayout(false);
}
diff --git a/interface/FormAbout.resx b/interface/FormAbout.resx
index ba8ad9d4..bb590558 100644
--- a/interface/FormAbout.resx
+++ b/interface/FormAbout.resx
@@ -126,10 +126,21 @@ https://autoscreen.sourceforge.io/
GitHub Project Site
https://github.com/gavinkendall/autoscreen/
+
+
+ 2.3.4.0
+
+You can now configure Auto Screen Capture to email screenshots with SMTP (without having to edit the application.xml file) and/or transfer them to a file server with SFTP. These settings are stored in their own XML files named smtp.xml and sftp.xml respectively so you can configure them to be in different locations with autoscreen.conf if you prefer.
+
+I fixed the -config, -applicationFocusDelayBefore, and -applicationFocusDelayAfter command line options. These became screwed up in 2.3.3.8 after I merged in code from an optimization initiative.
+
+The Help button is finally usable, but I still have to write all the documentation for it so at this time there's only the "Welcome" page available.
+
+Triggers have been rewritten. I haven't spent much time on the new wizard-style interface for them but their functionality remains the same. I've introduced a new Trigger for File Transfer (SFTP).
Codename "Boombayah"
-2.3.4.0 Configure SMTP and SFTP.
+2.3.4.0 Screenshots can be sent to a file server either from the main interface window or with a Trigger. The SMTP and SFTP settings are in their own XML files and can be configured. Help system is available but still early in development.
2.3.3.9 Dashboard introduced so you can have an overview of all screens and regions.
2.3.3.8 Screen now has Source (such as Graphics Card and Operating System), X, Y, Width, and Height. Removed "Resolution Ratio" option for better screen capture performance. Removed internal screen dictionary refresh from Windows because we now use X, Y, Width, and Height either from Graphics Card or from Operating System and these values can now be adjusted. Module tab page layout style changed to be multi-line. Refactored code to reduce usage of static classes and static variables for better memory management. Removed calls to GC Collect. Changed screen capture method. "Region Select / Auto Save" region is no longer created when application initialized. "Region Select / Auto Save" screenshots are now shown in all screenshot tabs.
2.3.3.7 Memory leak fix.
@@ -424,6 +435,19 @@ IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY C
If the disclaimer of warranty and limitation of liability provided above cannot be given local legal effect according to their terms, reviewing courts shall apply local law that most closely approximates an absolute waiver of all civil liability in connection with the Program, unless a warranty or assumption of liability accompanies a copy of the Program in return for a fee.
END OF TERMS AND CONDITIONS
+
+
+ Hi :)
+
+I hope you enjoy using Auto Screen Capture. I developed the application for my own purposes many years ago but if you find it useful then please consider putting in a small donation over at https://paypal.me/codewalker777
+
+Also, if you want to keep in touch, please feel free to follow me on Twitter and subscribe to my YouTube channel.
+
+Twitter
+https://twitter.com/autoscreen2
+
+YouTube Channel
+https://www.youtube.com/user/gavinkendall/
diff --git a/modules/triggers/FormTrigger.Designer.cs b/modules/triggers/FormTrigger.Designer.cs
index 694e5b37..7ef11d95 100644
--- a/modules/triggers/FormTrigger.Designer.cs
+++ b/modules/triggers/FormTrigger.Designer.cs
@@ -137,6 +137,7 @@ private void InitializeComponent()
this.listBoxCondition.TabIndex = 5;
this.listBoxCondition.TabStop = false;
this.listBoxCondition.Visible = false;
+ this.listBoxCondition.SelectedIndexChanged += new System.EventHandler(this.listBoxCondition_SelectedIndexChanged);
//
// groupBox
//
diff --git a/modules/triggers/FormTrigger.cs b/modules/triggers/FormTrigger.cs
index 7fefff0a..7cd8398a 100644
--- a/modules/triggers/FormTrigger.cs
+++ b/modules/triggers/FormTrigger.cs
@@ -148,6 +148,8 @@ private void FormTrigger_Load(object sender, EventArgs e)
numericUpDownMillisecondsInterval.Value = 0;
}
+ Text += " (BETA)";
+
_pageIndex = 1;
ShowPage();
@@ -338,8 +340,8 @@ private void LoadConditions()
listBoxCondition.Items.Add(new TriggerCondition(TriggerConditionType.Time, "Time").Description);
listBoxCondition.Items.Add(new TriggerCondition(TriggerConditionType.DayTime, "Day/Time").Description);
listBoxCondition.Items.Add(new TriggerCondition(TriggerConditionType.BeforeScreenshotTaken, "Before Screenshot Taken").Description);
- listBoxCondition.Items.Add(new TriggerCondition(TriggerConditionType.BeforeScreenshotSaved, "Before Screenshot Saved").Description);
- listBoxCondition.Items.Add(new TriggerCondition(TriggerConditionType.AfterScreenshotSaved, "After Screenshot Saved").Description);
+ listBoxCondition.Items.Add(new TriggerCondition(TriggerConditionType.BeforeScreenshotReferencesSaved, "Before Screenshot References Saved").Description);
+ listBoxCondition.Items.Add(new TriggerCondition(TriggerConditionType.AfterScreenshotReferencesSaved, "After Screenshot References Saved").Description);
listBoxCondition.SelectedIndex = 0;
}
@@ -463,11 +465,6 @@ private void LoadModuleItems()
}
}
- private void listBoxAction_SelectedIndexChanged(object sender, EventArgs e)
- {
- LoadModuleItems();
- }
-
private void buttonBack_Click(object sender, EventArgs e)
{
_pageIndex--;
@@ -490,6 +487,8 @@ private void ShowPage()
{
// Page 1 - Condition
case 1:
+ ShowConditionHelpText();
+
groupBox.Text = "Condition";
buttonBack.Enabled = false;
buttonNext.Enabled = true;
@@ -584,6 +583,8 @@ private void ShowPage()
// Page 3 - Action
case 3:
+ ShowActionHelpText();
+
groupBox.Text = "Action";
buttonNext.Enabled = true;
buttonFinish.Enabled = false;
@@ -692,5 +693,219 @@ private void ShowPage()
break;
}
}
+
+ private void listBoxCondition_SelectedIndexChanged(object sender, EventArgs e)
+ {
+ ShowConditionHelpText();
+ }
+
+ private void listBoxAction_SelectedIndexChanged(object sender, EventArgs e)
+ {
+ LoadModuleItems();
+
+ ShowActionHelpText();
+ }
+
+ private void ShowConditionHelpText()
+ {
+ switch (listBoxCondition.SelectedIndex)
+ {
+ // Application Startup
+ case 0:
+ textBoxHelp.Text = "When the application is started. This could be as a result of Auto Screen Capture being started by double-clicking its icon or running autoscreen.exe from a command line terminal.";
+ break;
+
+ // Application Exit
+ case 1:
+ textBoxHelp.Text = "When the application is going to exit or quit.";
+ break;
+
+ // Interface Closing
+ case 2:
+ textBoxHelp.Text = "When the application's main interface window is going to close.";
+ break;
+
+ // Interface Hiding
+ case 3:
+ textBoxHelp.Text = "When the application's main interface window is about to be hidden.";
+ break;
+
+ // Interface Showing
+ case 4:
+ textBoxHelp.Text = "When the application's main interface window is about to be shown.";
+ break;
+
+ // Limit Reached
+ case 5:
+ textBoxHelp.Text = "When the number of screen capture cycles reach the specified limit.";
+ break;
+
+ // Screen Capture Started
+ case 6:
+ textBoxHelp.Text = "When a screen capture session starts. The Start Screen Capture button is clicked or Start Screen Capture is selected from the system tray icon menu.";
+ break;
+
+ // Screen Capture Stopped
+ case 7:
+ textBoxHelp.Text = "When the currently running screen capture session stops. The Stop Screen Capture button is clicked or Stop Screen Capture is selected from the system tray icon menu.";
+ break;
+
+ // After Screenshot Taken
+ case 8:
+ textBoxHelp.Text = "When a screenshot has been taken after it has been saved to disk.";
+ break;
+
+ // Date/Time
+ case 9:
+ textBoxHelp.Text = "When a specified date and time is encountered.";
+ break;
+
+ // Time
+ case 10:
+ textBoxHelp.Text = "When a specified time is encountered.";
+ break;
+
+ // Day/Time
+ case 11:
+ textBoxHelp.Text = "When a specified day and time is encountered.";
+ break;
+
+ // Before Screenshot Taken
+ case 12:
+ textBoxHelp.Text = "When a screenshot is about to be taken before it has been saved to disk.";
+ break;
+
+ // Before Screenshot References Saved
+ case 13:
+ textBoxHelp.Text = "When screenshot references are about to be saved to disk during a recurring five minute maintenance timer.";
+ break;
+
+ // After Screenshot References Saved
+ case 14:
+ textBoxHelp.Text = "When screenshot references have been saved to disk during a recurring five minute maintenance timer.";
+ break;
+ }
+ }
+
+ private void ShowActionHelpText()
+ {
+ switch (listBoxAction.SelectedIndex)
+ {
+ // Exit Application
+ case 0:
+ textBoxHelp.Text = "Exit the application.";
+ break;
+
+ // Hide Interface
+ case 1:
+ textBoxHelp.Text = "Hide the application's main interface window.";
+ break;
+
+ // Run Editor
+ case 2:
+ textBoxHelp.Text = "Run a specified Editor.";
+ break;
+
+ // Show Interface
+ case 3:
+ textBoxHelp.Text = "Show the application's main interface window.";
+ break;
+
+ // Start Screen Capture
+ case 4:
+ textBoxHelp.Text = "Start a screen capture session.";
+ break;
+
+ // Stop Screen Capture
+ case 5:
+ textBoxHelp.Text = "Stop the currently running screen capture session.";
+ break;
+
+ // Email Screenshot (SMTP)
+ case 6:
+ textBoxHelp.Text = "Email screenshots using the configured email server settings.";
+ break;
+
+ // Set Screen Capture Interval
+ case 7:
+ textBoxHelp.Text = "Sets the timer's screen capture interval.";
+ break;
+
+ // Activate Screen
+ case 8:
+ textBoxHelp.Text = "Activates a specified Screen.";
+ break;
+
+ // Activate Region
+ case 9:
+ textBoxHelp.Text = "Activates a specified Region.";
+ break;
+
+ // Activate Schedule
+ case 10:
+ textBoxHelp.Text = "Activates a specified Schedule.";
+ break;
+
+ // Activate Macro Tag
+ case 11:
+ textBoxHelp.Text = "Activate a specified Macro Tag.";
+ break;
+
+ // Activate Trigger
+ case 12:
+ textBoxHelp.Text = "Activate a specified Trigger.";
+ break;
+
+ // Deactivate Screen
+ case 13:
+ textBoxHelp.Text = "Deactivate a specified Screen.";
+ break;
+
+ // Deactivate Region
+ case 14:
+ textBoxHelp.Text = "Deactivate a specified Region.";
+ break;
+
+ // Deactivate Schedule
+ case 15:
+ textBoxHelp.Text = "Deactivate a specified Schedule.";
+ break;
+
+ // Deactivate Macro Tag
+ case 16:
+ textBoxHelp.Text = "Deactivate a specified Macro Tag.";
+ break;
+
+ // Deactivate Trigger
+ case 17:
+ textBoxHelp.Text = "Deactivate a specified Trigger.";
+ break;
+
+ // Delete Screenshots
+ case 18:
+ textBoxHelp.Text = "Delete a series of screenshots.";
+ break;
+
+ // Apply Label
+ case 19:
+ textBoxHelp.Text = "Apply a specified label to each screenshot during a screen capture session.";
+ break;
+
+ // Set Active Window Title
+ case 20:
+ textBoxHelp.Text = "Set the text used for comparison against the title of the active window.";
+ break;
+
+ // Set Application Focus
+ case 21:
+ textBoxHelp.Text = "Set the name of the process to be forced into focus.";
+ break;
+
+ // File Transfer Screenshot (SFTP)
+ case 22:
+ textBoxHelp.Text = "Transfer screenshots to a file server using the configured File Transfer settings.";
+ break;
+ }
+ }
}
}
\ No newline at end of file
diff --git a/modules/triggers/TriggerCollection.cs b/modules/triggers/TriggerCollection.cs
index 8dbf23e7..9043a809 100644
--- a/modules/triggers/TriggerCollection.cs
+++ b/modules/triggers/TriggerCollection.cs
@@ -255,7 +255,7 @@ public bool LoadXmlFileAndAddTriggers(Config config, FileSystem fileSystem, Log
{
Active = true,
Name = $"Keep screenshots for {days} days",
- ConditionType = TriggerConditionType.BeforeScreenshotSaved,
+ ConditionType = TriggerConditionType.BeforeScreenshotReferencesSaved,
ActionType = TriggerActionType.DeleteScreenshots,
Date = DateTime.Now,
Time = DateTime.Now,
@@ -334,7 +334,7 @@ public bool LoadXmlFileAndAddTriggers(Config config, FileSystem fileSystem, Log
{
Active = true,
Name = "Keep screenshots for 30 days",
- ConditionType = TriggerConditionType.BeforeScreenshotSaved,
+ ConditionType = TriggerConditionType.BeforeScreenshotReferencesSaved,
ActionType = TriggerActionType.DeleteScreenshots,
Date = DateTime.Now,
Time = DateTime.Now,
diff --git a/readme.txt b/readme.txt
index e7ac9e8a..f5ddae35 100644
--- a/readme.txt
+++ b/readme.txt
@@ -7,7 +7,7 @@ Summary
-------
Auto Screen Capture is a small and portable screen capture utility for gamers, designers, and testers.
-The information presented in this README refers to the latest version (2.3.3.9).
+(The information presented in this README refers to version 2.3.3.9)
The application enables you to automatically take screenshots at a chosen interval. For example, you may
want to capture the progress of playing through a game's level or track your progress on a long project.
diff --git a/interface/main/FormMain-Screenshots.cs b/interface/main/FormMain-Screenshots.cs
index 7e05d611..8585f2a8 100644
--- a/interface/main/FormMain-Screenshots.cs
+++ b/interface/main/FormMain-Screenshots.cs
@@ -31,18 +31,18 @@ namespace AutoScreenCapture
public partial class FormMain : Form
{
///
/// Saves screenshots and refreshes the calendar every five minutes (300000 milliseconds).
///
///
///
private void timerPerformMaintenance_Tick(object sender, EventArgs e)
{
- RunTriggersOfConditionType(TriggerConditionType.BeforeScreenshotSaved);
+ RunTriggersOfConditionType(TriggerConditionType.BeforeScreenshotReferencesSaved);
- // Save screenshots.
- SaveScreenshots();
+ // Save screenshot references.
+ SaveScreenshotReferences();
- RunTriggersOfConditionType(TriggerConditionType.AfterScreenshotSaved);
+ RunTriggersOfConditionType(TriggerConditionType.AfterScreenshotReferencesSaved);
}
///
@@ -160,7 +160,7 @@ private void fileTransferScreenshot_Click(object sender, EventArgs e)
}
}
- private void SaveScreenshots()
+ private void SaveScreenshotReferences()
{
if (runSaveScreenshotsThread == null)
{
@@ -31,18 +31,18 @@ namespace AutoScreenCapture
{
///
- /// Saves screenshots and refreshes the calendar every five minutes (300000 milliseconds).
+ /// Saves screenshot references every five minutes (300000 milliseconds).
///
///
diff --git a/modules/triggers/TriggerConditionType.cs b/modules/triggers/TriggerConditionType.cs
index fd9a5421..3d6bc79b 100644
--- a/modules/triggers/TriggerConditionType.cs
+++ b/modules/triggers/TriggerConditionType.cs
@@ -91,13 +91,13 @@ public enum TriggerConditionType
BeforeScreenshotTaken = 12,
///
/// When a screenshot is about to be saved.
///
- BeforeScreenshotSaved = 13,
+ BeforeScreenshotReferencesSaved = 13,
///
/// When a screenshot is saved.
///
- AfterScreenshotSaved = 14
+ AfterScreenshotReferencesSaved = 14
}
}
\ No newline at end of file
@@ -91,13 +91,13 @@ public enum TriggerConditionType
BeforeScreenshotTaken = 12,
///
- /// When a screenshot is about to be saved.
+ /// When screenshot references are about to be saved.
///
@@ -91,13 +91,13 @@ public enum TriggerConditionType
///
- /// When a screenshot is saved.
+ /// When screenshot references are saved.
///